@@ -1,9 +1,23 @@
+def_ren <- new.env(parent = emptyenv())
+
 .onLoad <- function(...) {
   register_s3_method("knitr", "knit_print", "gganim")
   register_s3_method("knitr", "knit_print", "gif_image")
   register_s3_method("knitr", "knit_print", "video_file")
   register_s3_method("knitr", "knit_print", "sprite_image")
 
+  def_ren$has_proper <- TRUE
+  if (requireNamespace('gifski', quietly = TRUE)) {
+    def_ren$renderer <- gifski_renderer()
+  } else if (requireNamespace('magick', quietly = TRUE)) {
+    def_ren$renderer <- magick_renderer()
+  } else if (requireNamespace('av', quietly = TRUE)) {
+    def_ren$renderer <- av_renderer()
+  } else {
+    def_ren$renderer <- file_renderer()
+    def_ren$has_proper <- FALSE
+  }
+
   invisible()
 }
 
